@@ -46,7 +46,7 @@ class MXFlyer:
     def complete(self):
         def callback_motion(value, old_value, **kwargs):
             print(f"old: {old_value} -> new: {value}")
-            if int(old_value) == 1 and int(value) == 0:
+            if old_value == 1 and value == 0:
                 return True
             else:
                 return False
@@ -100,7 +100,6 @@ class MXFlyer:
     #         yield item
 
     def collect_asset_docs(self):
-
         asset_docs_cache = []
 
         # Get the Resource which was produced when the detector was staged.
